@@ -29,7 +29,6 @@ class ServerClient(ModeRageClient):
             self._logger.debug(f'Could not connect to server at [{self._root_url}]')
             return False
 
-
     def save(self, meta_category, meta, parents=None, files=None, keep_originals=False):
         """
         Save using moderage server
@@ -59,7 +58,7 @@ class ServerClient(ModeRageClient):
 
         return Experiment(experiment_json, self._mr_service, experiment_cache_location)
 
-    def load(self, id, meta_category, ignore_files=False):
+    def load(self, id, meta_category, lazy_file_download=True):
         """
         Load from moderage server
         """
@@ -73,28 +72,35 @@ class ServerClient(ModeRageClient):
         if not experiment_file_location.exists():
             experiment_file_location.mkdir(parents=True)
 
-        if not ignore_files:
+        self._logger.info(f'[{len(experiment["files"])}] files found')
 
-            self._logger.info(f'[{len(experiment["files"])}] files found')
+        # download the files from their uris
+        for file_info in experiment['files']:
 
-            # download the files from their uris
-            for file_info in experiment['files']:
+            cached_filename = experiment_file_location.joinpath(file_info['id'])
 
+            # If we have not cached the file already, download it and move it to the cache directory
+            cached = cached_filename.exists()
+
+            if lazy_file_download:
+                file_info['downloaded'] = cached
+            else:
                 cached_filename = experiment_file_location.joinpath(file_info['id'])
 
                 # If we have not cached the file already, download it and move it to the cache directory
-                if not cached_filename.exists():
+                if not cached:
                     self._logger.info(f'Downloading file: [{file_info["filename"]}]')
-                    self._download_file(file_info, str(cached_filename))
+                    self.download_file(file_info, str(cached_filename))
                 else:
                     self._logger.info(f'File found in cache: [{file_info["filename"]}]')
 
+                file_info['downloaded'] = True
+
         experiment_cache_location = self._get_experiment_cache_location(id, meta_category)
 
         return Experiment(experiment, self._mr_service, experiment_cache_location)
 
-
-    def _download_file(self, file_info, cached_filename):
+    def download_file(self, file_info, cached_filename):
 
         location = file_info['location']
         startswith = location.startswith('https://s3.amazonaws.com')
@@ -204,4 +210,3 @@ class ServerClient(ModeRageClient):
                 os.remove(local_filename)
 
         return upload_response.json()
-
